==> linux-show-player_0.5.orig.tar.gz: linux-show-player-0.5/lisp/modules/replay_gain/i18n/replay_gain_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>ReplayGain</name>
    <message>
        <location filename="../gain_ui.py" line="101"/>
        <source>ReplayGain / Normalization</source>
        <translation>Gain de lecture / normalisation</translation>
    </message>
    <message>
        <location filename="../replay_gain.py" line="163"/>
        <source>Calculate</source>
        <translation>Calculer</translation>
    </message>
    <message>
        <location filename="../replay_gain.py" line="168"/>
        <source>Reset all</source>
        <translation>Tout réinitialiser</translation>
    </message>
    <message>
        <location filename="../replay_gain.py" line="173"/>
        <source>Reset selected</source>
        <translation>Réinitialiser la séléction</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="103"/>
        <source>Threads number</source>
        <translation>Nombre de fils</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="104"/>
        <source>Apply only to selected media</source>
        <translation>Ne s&apos;applique seulement au média sélectionné</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="106"/>
        <source>ReplayGain to (dB SPL)</source>
        <translation>Gain de lecture à (dB SPL)</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="108"/>
        <source>Normalize to (dB)</source>
        <translation>Normaliser à (dB)</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="132"/>
        <source>Processing files ...</source>
        <translation>Fichier en cours de traitement ...</translation>
    </message>
</context>
</TS>

==> linux-show-player_0.5.3.orig.tar.gz: linux-show-player-0.5.3/lisp/modules/replay_gain/i18n/replay_gain_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>ReplayGain</name>
    <message>
        <location filename="../gain_ui.py" line="101"/>
        <source>ReplayGain / Normalization</source>
        <translation>Gain de lecture / normalisation</translation>
    </message>
    <message>
        <location filename="../replay_gain.py" line="163"/>
        <source>Calculate</source>
        <translation>Calculer</translation>
    </message>
    <message>
        <location filename="../replay_gain.py" line="168"/>
        <source>Reset all</source>
        <translation>Tout réinitialiser</translation>
    </message>
    <message>
        <location filename="../replay_gain.py" line="173"/>
        <source>Reset selected</source>
        <translation>Réinitialiser la sélection</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="103"/>
        <source>Threads number</source>
        <translation>Nombre de fils</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="104"/>
        <source>Apply only to selected media</source>
        <translation>N&apos;appliquer qu&apos;au média sélectionné</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="106"/>
        <source>ReplayGain to (dB SPL)</source>
        <translation>Gain de lecture à (dB SPL)</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="108"/>
        <source>Normalize to (dB)</source>
        <translation>Normaliser à (dB)</translation>
    </message>
    <message>
        <location filename="../gain_ui.py" line="132"/>
        <source>Processing files ...</source>
        <translation>Fichier en cours de traitement ...</translation>
    </message>
</context>
</TS>
